<?php

namespace Drupal\image_field_caption;

use Drupal\Core\Form\FormStateInterface;
use Drupal\image\Plugin\Field\FieldType\ImageItem;

/**
 * Class to provide functionlality for ImageCaptionItem.
 */
class ImageCaptionItem extends ImageItem {

  /**
   * {@inheritdoc}
   */
  public static function defaultFieldSettings() {
    return [
      'default_image' => [
        'caption' => '',
      ],
      'caption_field' => FALSE,
      'caption_field_required' => FALSE,
    ] + parent::defaultFieldSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
    // Get base form from ImageItem.
    $element = parent::fieldSettingsForm($form, $form_state);
    // Get field settings.
    $settings = $this->getSettings();
    // Get the default field settings.
    $settings_default = self::defaultFieldSettings();

    // Add caption option.
    $element['caption_field'] = [
      '#type' => 'checkbox',
      '#title' => t('Enable <em>Caption</em> field'),
      '#default_value' => (!empty($settings['caption_field'])) ? $settings['caption_field'] : $settings_default['caption_field'],
      '#description' => t('Adds an extra text area for captions on image fields.'),
      '#weight' => 13,
    ];
    // Add caption (required) option.
    $element['caption_field_required'] = [
      '#type' => 'checkbox',
      '#title' => t('<em>Caption</em> field required'),
      '#default_value' => (!empty($settings['caption_field_required'])) ? $settings['caption_field_required'] : $settings_default['caption_field_required'],
      '#description' => '',
      '#weight' => 14,
      '#states' => [
        'visible' => [
          ':input[name="settings[image_caption_field]"]' => ['checked' => TRUE],
        ],
      ],
    ];
    // Add default caption.
    $element['default_image']['caption'] = [
      '#type' => 'value',
      '#value' => (!empty($settings['default_image']['caption'])) ? $settings['default_image']['caption'] : $settings_default['default_image']['caption'],
    ];

    return $element;
  }
}
